==> qtjambi-designer-5.15.7-sources.jar: io/qt/designer/QDesignerFormEditorPluginInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerFormEditorPluginInterface</p>
 */
public interface QDesignerFormEditorPluginInterface extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerFormEditorPluginInterface}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerFormEditorPluginInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerFormEditorPluginInterface.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.widgets.QAction action(){
                return action_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.widgets.QAction action_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.designer.QDesignerFormEditorInterface core(){
                return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public void initialize(io.qt.designer.QDesignerFormEditorInterface core){
                initialize_native_QDesignerFormEditorInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(core));
            }
            private native static void initialize_native_QDesignerFormEditorInterface_ptr(long __this__nativeId, long core);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isInitialized(){
                return isInitialized_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean isInitialized_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerFormEditorPluginInterface instance);
        
        @io.qt.QtUninvokable
        public abstract io.qt.widgets.QAction action();
        
        private native static io.qt.widgets.QAction action_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract io.qt.designer.QDesignerFormEditorInterface core();
        
        private native static io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract void initialize(io.qt.designer.QDesignerFormEditorInterface core);
        
        private native static void initialize_native_QDesignerFormEditorInterface_ptr(long __this__nativeId, long core);
        
        @io.qt.QtUninvokable
        public abstract boolean isInitialized();
        
        private native static boolean isInitialized_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @io.qt.QtUninvokable
    public io.qt.widgets.QAction action();
    
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerFormEditorInterface core();
    
    @io.qt.QtUninvokable
    public void initialize(io.qt.designer.QDesignerFormEditorInterface core);
    
    @io.qt.QtUninvokable
    public boolean isInitialized();
    
}

==> qtjambi-designer-6.2-sources.jar: io/qt/designer/QDesignerFormEditorPluginInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerFormEditorPluginInterface</p>
 */
public interface QDesignerFormEditorPluginInterface extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerFormEditorPluginInterface}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerFormEditorPluginInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerFormEditorPluginInterface.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.gui.QAction action(){
                return action_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.gui.QAction action_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.designer.QDesignerFormEditorInterface core(){
                return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public void initialize(io.qt.designer.QDesignerFormEditorInterface core){
                initialize_native_QDesignerFormEditorInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(core));
            }
            private native static void initialize_native_QDesignerFormEditorInterface_ptr(long __this__nativeId, long core);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isInitialized(){
                return isInitialized_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean isInitialized_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerFormEditorPluginInterface instance);
        
        @io.qt.QtUninvokable
        public abstract io.qt.gui.QAction action();
        
        private native static io.qt.gui.QAction action_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract io.qt.designer.QDesignerFormEditorInterface core();
        
        private native static io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract void initialize(io.qt.designer.QDesignerFormEditorInterface core);
        
        private native static void initialize_native_QDesignerFormEditorInterface_ptr(long __this__nativeId, long core);
        
        @io.qt.QtUninvokable
        public abstract boolean isInitialized();
        
        private native static boolean isInitialized_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @io.qt.QtUninvokable
    public io.qt.gui.QAction action();
    
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerFormEditorInterface core();
    
    @io.qt.QtUninvokable
    public void initialize(io.qt.designer.QDesignerFormEditorInterface core);
    
    @io.qt.QtUninvokable
    public boolean isInitialized();
    
}
